==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/TextColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { TextColumnDescription } from "./TextColumnDescription";
/**
 * @hidden
 */
export let TextColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class TextColumnDescriptionMetadata extends Base {
        static b(a) {
            if (TextColumnDescriptionMetadata.a == null) {
                TextColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TextColumnDescriptionMetadata.c(TextColumnDescriptionMetadata.a);
            }
            if (a.k(TextColumnDescriptionMetadata.a)) {
                return;
            }
            a.ab(TextColumnDescriptionMetadata.a);
        }
        static c(a) {
            DataGridColumnDescriptionMetadata.c(a);
            a.item("EditorType", "ExportedType:string:EditorType");
            a.item("EditorType@names", "Default;Text;Numeric;Date;Combo");
            a.item("EditorDataSourceRef", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)DataRef::object");
            a.item("EditorDataSource", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)ExportedType:BaseDataSource:BaseDataSource");
            a.item("EditorTextField", "String");
            a.item("EditorValueField", "String");
        }
        static d(a) {
            TextColumnDescriptionMetadata.b(a);
            a.ad("TextColumn", () => new TextColumnDescription());
            a.ac("TextColumn", TextColumnDescriptionMetadata.a);
        }
    }
    TextColumnDescriptionMetadata.$t = /*@__PURE__*/ markType(TextColumnDescriptionMetadata, 'TextColumnDescriptionMetadata');
    TextColumnDescriptionMetadata.a = null;
    return TextColumnDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/TextColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { TextColumnDescription } from "./TextColumnDescription";
/**
 * @hidden
 */
export let TextColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class TextColumnDescriptionMetadata extends Base {
        static b(a) {
            if (TextColumnDescriptionMetadata.a == null) {
                TextColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TextColumnDescriptionMetadata.c(TextColumnDescriptionMetadata.a);
            }
            if (a.k(TextColumnDescriptionMetadata.a)) {
                return;
            }
            a.ac(TextColumnDescriptionMetadata.a);
        }
        static c(a) {
            DataGridColumnDescriptionMetadata.c(a);
            a.item("EditorType", "ExportedType:string:EditorType");
            a.item("EditorType@names", "Default;Text;Numeric;Date;Combo");
            a.item("EditorDataSourceRef", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)DataRef::object");
            a.item("EditorDataSource", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)ExportedType:BaseDataSource:BaseDataSource");
            a.item("EditorTextField", "String");
            a.item("EditorValueField", "String");
        }
        static d(a) {
            TextColumnDescriptionMetadata.b(a);
            a.ae("TextColumn", () => new TextColumnDescription());
            a.ad("TextColumn", TextColumnDescriptionMetadata.a);
        }
    }
    TextColumnDescriptionMetadata.$t = /*@__PURE__*/ markType(TextColumnDescriptionMetadata, 'TextColumnDescriptionMetadata');
    TextColumnDescriptionMetadata.a = null;
    return TextColumnDescriptionMetadata;
})();
